@@ -22,9 +22,9 @@ for dfile in dylib_list:
     )
 
 os.system(
-    'codesign --timestamp --options runtime --verify --verbose=4 --force --sign "Developer ID Application: European Spallation Source Eric (W2AG9MPZ43)" SasView5.0.app/Contents/MacOS/base_library.zip'
+    'codesign --timestamp --options runtime --verify --verbose=4 --force --sign "Developer ID Application: European Spallation Source Eric (W2AG9MPZ43)" SasView5.app/Contents/MacOS/base_library.zip'
 )
 
 os.system(
-    'codesign --timestamp --options runtime --verify --verbose=4 --force --sign "Developer ID Application: European Spallation Source Eric (W2AG9MPZ43)" SasView5.0.app'
+    'codesign --timestamp --options runtime --verify --verbose=4 --force --sign "Developer ID Application: European Spallation Source Eric (W2AG9MPZ43)" SasView5.app'
 )
