@@ -683,6 +683,10 @@ class GenericScatteringCalculator(QtWidgets.QDialog, Ui_GenericScatteringCalcula
                                                     int(self.graph_num))
             zeros = numpy.ones(data.data.size, dtype=bool)
             data.mask = zeros
+            data.xmin = self.data.xmin
+            data.xmax = self.data.xmax
+            data.ymin = self.data.ymin
+            data.ymax = self.data.ymax
 
             self.graph_num += 1
             # TODO
@@ -863,6 +867,12 @@ class Plotter3DWidget(PlotterBase):
         """
         return
 
+    def closeEvent(self, event):
+        """
+        Overwrite the close event adding helper notification
+        """
+        event.accept()
+
 
 class Plotter3D(QtWidgets.QDialog, Plotter3DWidget):
     def __init__(self, parent=None, graph_title=''):
