@@ -29,7 +29,7 @@ from sas.qtgui.Utilities.GridPanel import BatchOutputPanel
 from sas.qtgui.Utilities.ResultPanel import ResultPanel
 
 from sas.qtgui.Utilities.ReportDialog import ReportDialog
-from sas.qtgui.MainWindow.UI.AcknowledgementsUI import Ui_Acknowledgements
+from sas.qtgui.MainWindow.Acknowledgements import Acknowledgements
 from sas.qtgui.MainWindow.AboutBox import AboutBox
 from sas.qtgui.MainWindow.WelcomePanel import WelcomePanel
 from sas.qtgui.MainWindow.CategoryManager import CategoryManager
@@ -57,13 +57,6 @@ from sas.qtgui.Utilities.FileConverter import FileConverterWidget
 
 logger = logging.getLogger(__name__)
 
-class Acknowledgements(QDialog, Ui_Acknowledgements):
-    def __init__(self, parent=None):
-        QDialog.__init__(self, parent)
-        self.setupUi(self)
-        # disable the context help icon
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
-
 
 class GuiManager(object):
     """
@@ -97,6 +90,7 @@ class GuiManager(object):
 
         # Currently displayed perspective
         self._current_perspective = None
+        self.loadedPerspectives = {}
 
         # Populate the main window with stuff
         self.addWidgets()
@@ -126,11 +120,7 @@ class GuiManager(object):
         Populate the main window with widgets
         """
         # Preload all perspectives
-        loaded_dict = {}
-        for name, perspective in Perspectives.PERSPECTIVES.items():
-            loaded_perspective = perspective(parent=self)
-            loaded_dict[name] = loaded_perspective
-        self.loadedPerspectives = loaded_dict
+        self.loadAllPerspectives()
 
         # Add FileDialog widget as docked
         self.filesWidget = DataExplorerWindow(self._parent, self, manager=self._data_manager)
@@ -187,6 +177,33 @@ class GuiManager(object):
         self.DataOperation = DataOperationUtilityPanel(self)
         self.FileConverter = FileConverterWidget(self)
 
+    def loadAllPerspectives(self):
+        # Close any existing perspectives to prevent multiple open instances
+        self.closeAllPerspectives()
+        # Load all perspectives
+        loaded_dict = {}
+        for name, perspective in Perspectives.PERSPECTIVES.items():
+            try:
+                loaded_perspective = perspective(parent=self)
+                loaded_dict[name] = loaded_perspective
+            except Exception as e:
+                logger.warning(f"Unable to load {name} perspective.\n{e}")
+        self.loadedPerspectives = loaded_dict
+
+    def closeAllPerspectives(self):
+        # Close all perspectives if they are open
+        if isinstance(self.loadedPerspectives, dict):
+            for name, perspective in self.loadedPerspectives.items():
+                try:
+                    perspective.setClosable(True)
+                    if self.subwindow in self._workspace.workspace.subWindowList():
+                        self._workspace.workspace.removeSubWindow(self.subwindow)
+                    perspective.close()
+                except Exception as e:
+                    logger.warning(f"Unable to close {name} perspective\n{e}")
+        self.loadedPerspectives = {}
+        self._current_perspective = None
+
     def addCategories(self):
         """
         Make sure categories.json exists and if not compile it and install in ~/.sasview
@@ -524,7 +541,7 @@ class GuiManager(object):
         self.communicate.updateTheoryFromPerspectiveSignal.connect(self.updateTheoryFromPerspective)
         self.communicate.deleteIntermediateTheoryPlotsSignal.connect(self.deleteIntermediateTheoryPlotsByModelID)
         self.communicate.plotRequestedSignal.connect(self.showPlot)
-        self.communicate.plotFromFilenameSignal.connect(self.showPlotFromFilename)
+        self.communicate.plotFromNameSignal.connect(self.showPlotFromName)
         self.communicate.updateModelFromDataOperationPanelSignal.connect(self.updateModelFromDataOperationPanel)
         self.communicate.activeGraphsSignal.connect(self.updatePlotItems)
 
@@ -651,6 +668,8 @@ class GuiManager(object):
         Menu Save Project
         """
         filename = self.filesWidget.saveProject()
+        if not filename:
+            return
 
         # datasets
         all_data = self.filesWidget.getSerializedData()
@@ -661,7 +680,7 @@ class GuiManager(object):
         # Save from all serializable perspectives
         # Analysis should return {data-id: serialized-state}
         for name, per in self.loadedPerspectives.items():
-            if hasattr(per, 'isSerializable') and per.isSerializable:
+            if hasattr(per, 'isSerializable') and per.isSerializable():
                 analysis = per.serializeAll()
                 for key, value in analysis.items():
                     if key in final_data:
@@ -1169,12 +1188,12 @@ class GuiManager(object):
         self.filesWidget.model.appendRow(new_item)
         self._data_manager.add_data(new_datalist_item)
 
-    def showPlotFromFilename(self, filename):
+    def showPlotFromName(self, name):
         """
         Pass the show plot request to the data explorer
         """
         if hasattr(self, "filesWidget"):
-            self.filesWidget.displayFile(filename=filename, is_data=True)
+            self.filesWidget.displayDataByName(name=name, is_data=True)
 
     def showPlot(self, plot, id):
         """
