@@ -246,12 +246,12 @@ class DataExplorerTest(unittest.TestCase):
         QMessageBox.question = MagicMock(return_value=QMessageBox.No)
 
         # Populate the model
-        item1 = QStandardItem(True)
+        item1 = HashableStandardItem(True)
         item1.setCheckable(True)
         item1.setCheckState(Qt.Checked)
         item1.setText("item 1")
         self.form.theory_model.appendRow(item1)
-        item2 = QStandardItem(True)
+        item2 = HashableStandardItem(True)
         item2.setCheckable(True)
         item2.setCheckState(Qt.Unchecked)
         item2.setText("item 2")
@@ -755,6 +755,108 @@ class DataExplorerTest(unittest.TestCase):
         # See that the menu has been shown
         self.form.context_menu.exec_.assert_called_once()
 
+    def baseNameStateCheck(self):
+        """
+        Helper method for the Name Change Tests Below - Check the base state of the window
+        """
+        self.assertTrue(hasattr(self.form, "nameChangeBox"))
+        self.assertTrue(self.form.nameChangeBox.isModal())
+        self.assertEqual(self.form.nameChangeBox.windowTitle(), "Display Name Change")
+        self.assertFalse(self.form.nameChangeBox.isVisible())
+        self.assertIsNone(self.form.nameChangeBox.data)
+        self.assertIsNone(self.form.nameChangeBox.model_item)
+        self.assertFalse(self.form.nameChangeBox.txtCurrentName.isEnabled())
+        self.assertFalse(self.form.nameChangeBox.txtDataName.isEnabled())
+        self.assertFalse(self.form.nameChangeBox.txtFileName.isEnabled())
+        self.assertFalse(self.form.nameChangeBox.txtNewCategory.isEnabled())
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), "")
+        self.assertEqual(self.form.nameChangeBox.txtDataName.text(), "")
+        self.assertEqual(self.form.nameChangeBox.txtFileName.text(), "")
+        self.assertEqual(self.form.nameChangeBox.txtNewCategory.text(), "")
+
+    def testNameChange(self):
+        """
+        Test the display name change routines
+        """
+        # Define Constants
+        FILE_NAME = "cyl_400_20.txt"
+        FILE_NAME_APPENDED = FILE_NAME + " [1]"
+        TEST_STRING_1 = "test value change"
+        TEST_STRING_2 = "TEST VALUE CHANGE"
+        # Test base state of the name change window
+        self.baseNameStateCheck()
+        # Get Data1D
+        p_file=[FILE_NAME]
+        # Read in the file
+        output, message = self.form.readData(p_file)
+        key = list(output.keys())
+        output[key[0]].title = TEST_STRING_1
+        self.form.loadComplete((output, message))
+
+        # select the data and run name change routine
+        self.form.treeView.selectAll()
+        self.form.changeName()
+
+        # Test window state after adding data
+        self.assertTrue(self.form.nameChangeBox.isVisible())
+        self.assertIsNotNone(self.form.nameChangeBox.data)
+        self.assertIsNotNone(self.form.nameChangeBox.model_item)
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), FILE_NAME)
+        self.assertEqual(self.form.nameChangeBox.txtDataName.text(), TEST_STRING_1)
+        self.assertEqual(self.form.nameChangeBox.txtFileName.text(), FILE_NAME)
+        self.assertTrue(self.form.nameChangeBox.rbExisting.isChecked())
+        self.assertFalse(self.form.nameChangeBox.rbDataName.isChecked())
+        self.assertFalse(self.form.nameChangeBox.rbFileName.isChecked())
+        self.assertFalse(self.form.nameChangeBox.rbNew.isChecked())
+
+        # Take the existing name
+        self.form.nameChangeBox.cmdOK.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), FILE_NAME)
+
+        # Take the title
+        self.form.nameChangeBox.rbDataName.setChecked(True)
+        self.assertFalse(self.form.nameChangeBox.rbExisting.isChecked())
+        self.form.nameChangeBox.cmdOK.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), TEST_STRING_1)
+
+        # Take the file name again
+        self.form.nameChangeBox.rbFileName.setChecked(True)
+        self.assertFalse(self.form.nameChangeBox.rbExisting.isChecked())
+        self.form.nameChangeBox.cmdOK.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), FILE_NAME_APPENDED)
+
+        # Take the user-defined name, which is empty - should retain existing value
+        self.form.nameChangeBox.rbNew.setChecked(True)
+        self.assertFalse(self.form.nameChangeBox.rbExisting.isChecked())
+        self.form.nameChangeBox.cmdOK.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), FILE_NAME_APPENDED)
+
+        # Take a different user-defined name
+        self.form.nameChangeBox.rbNew.setChecked(True)
+        self.form.nameChangeBox.txtNewCategory.setText(TEST_STRING_2)
+        self.assertFalse(self.form.nameChangeBox.rbExisting.isChecked())
+        self.form.nameChangeBox.cmdOK.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), TEST_STRING_2)
+
+        # Test cancel button
+        self.form.nameChangeBox.rbNew.setChecked(True)
+        self.form.nameChangeBox.txtNewCategory.setText(TEST_STRING_1)
+        self.form.nameChangeBox.cmdCancel.click()
+        self.form.changeName()
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), TEST_STRING_2)
+        self.form.nameChangeBox.cmdOK.click()
+
+        # Test delete data
+        self.form.nameChangeBox.removeData(None)  # Nothing should happen
+        self.assertEqual(self.form.nameChangeBox.txtCurrentName.text(), TEST_STRING_2)
+        self.form.nameChangeBox.removeData([self.form.nameChangeBox.model_item])  # Should return to base state
+        self.baseNameStateCheck()
+
     def testShowDataInfo(self):
         """
         Test of the showDataInfo method
@@ -1067,6 +1169,5 @@ class DataExplorerTest(unittest.TestCase):
         # same data but must show, since different model
         self.assertFalse(self.form.isPlotShown(data4))
 
-
 if __name__ == "__main__":
     unittest.main()
