@@ -1,3 +1,5 @@
+from distutils.command.config import config
+
 import numpy
 import copy
 
@@ -11,6 +13,7 @@ from bumps import fitters
 import sas.qtgui.Utilities.LocalConfig as LocalConfig
 import sas.qtgui.Utilities.ObjectLibrary as ObjectLibrary
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
+from sas.qtgui.Perspectives.Fitting.Constraint import Constraint
 
 from sas.qtgui.Perspectives.Fitting.FittingWidget import FittingWidget
 from sas.qtgui.Perspectives.Fitting.ConstraintWidget import ConstraintWidget
@@ -185,6 +188,28 @@ class FittingWindow(QtWidgets.QTabWidget):
         """
         self.currentTab.createPageForParameters(parameters)
 
+    def updateFromConstraints(self, constraint_dict):
+        """
+        Updates all tabs with constraints present in *constraint_dict*, where
+        *constraint_dict*  keys are the fit page name, and the value is a
+        list of constraints. A constraint is represented by a list [value,
+        param, value_ex, validate, function] of attributes of a Constraint
+        object
+        """
+        for fit_page_name, constraint_list in constraint_dict.items():
+            tab = self.getTabByName(fit_page_name)
+            for constraint_param in constraint_list:
+                if constraint_param is not None and len(constraint_param) == 5:
+                    constraint = Constraint()
+                    constraint.value = constraint_param[0]
+                    constraint.func = constraint_param[4]
+                    constraint.param = constraint_param[1]
+                    constraint.value_ex = constraint_param[2]
+                    constraint.validate = constraint_param[3]
+                    tab.addConstraintToRow(constraint=constraint,
+                                           row=tab.getRowFromName(
+                                               constraint_param[1]))
+
     def onParamSave(self):
         self.currentTab.onCopyToClipboard("Save")
 
@@ -196,8 +221,9 @@ class FittingWindow(QtWidgets.QTabWidget):
         if self._allow_close:
             # reset the closability flag
             self.setClosable(value=False)
-            # Tell the MdiArea to close the container
-            self.parentWidget().close()
+            # Tell the MdiArea to close the container if it is visible
+            if self.parentWidget():
+                self.parentWidget().close()
             event.accept()
         else:
             # Maybe we should just minimize
@@ -221,15 +247,14 @@ class FittingWindow(QtWidgets.QTabWidget):
         self.tabs.append(tab)
         if data:
             self.updateFitDict(data, tab_name)
-        #self.maxIndex += 1
-        self.maxIndex = tab_index + 1
+        self.maxIndex = max([tab.tab_id for tab in self.tabs], default=0) + 1
 
         icon = QtGui.QIcon()
         if is_batch:
             icon.addPixmap(QtGui.QPixmap("src/sas/qtgui/images/icons/layers.svg"))
         self.addTab(tab, icon, tab_name)
         # Show the new tab
-        self.setCurrentWidget(tab);
+        self.setCurrentWidget(tab)
         # Notify listeners
         self.tabsModifiedSignal.emit()
 
@@ -279,14 +304,6 @@ class FittingWindow(QtWidgets.QTabWidget):
         page_name = "Const. & Simul. Fit"
         return page_name
 
-    def deleteAllTabs(self):
-        """
-        Explicitly deletes all the fittabs, leaving nothing.
-        This is in preparation for the project load step.
-        """
-        for tab_index in range(len(self.tabs)):
-            self.closeTabByIndex(tab_index)
-
     def closeTabByIndex(self, index):
         """
         Close/delete a tab with the given index.
@@ -392,9 +409,14 @@ class FittingWindow(QtWidgets.QTabWidget):
             # Find the first unassigned tab.
             # If none, open a new tab.
             available_tabs = [tab.acceptsData() for tab in self.tabs]
+            tab_ids = [tab.tab_id for tab in self.tabs]
 
             if tab_index is not None:
-                self.addFit(data, is_batch=is_batch, tab_index=tab_index)
+                if tab_index not in tab_ids:
+                    self.addFit(data, is_batch=is_batch, tab_index=tab_index)
+                else:
+                    self.setCurrentIndex(tab_index-1)
+                    self.swapData(data)
                 return
             if numpy.any(available_tabs):
                 first_good_tab = available_tabs.index(True)
@@ -482,3 +504,54 @@ class FittingWindow(QtWidgets.QTabWidget):
         """
         return self.currentWidget()
 
+    def getFitTabs(self):
+        """
+        Returns the list of fitting tabs
+        """
+        return [tab for tab in self.tabs if isinstance(tab, FittingWidget)]
+
+    def getActiveConstraintList(self):
+        """
+        Returns a list of the constraints for all fitting tabs. Constraints
+        are a tuple of strings (parameter, expression) e.g. ('M1.scale',
+        'M2.scale + 2')
+        """
+        constraints = []
+        for tab in self.getFitTabs():
+            tab_name = tab.modelName()
+            tab_constraints = tab.getConstraintsForModel()
+            constraints.extend((tab_name + "." + par, expr)
+                               for par, expr in tab_constraints)
+        return constraints
+
+    def getSymbolDictForConstraints(self):
+        """
+        Returns a dictionary containing all the symbols in  all constrained tabs
+        and their values.
+        """
+        symbol_dict = {}
+        for tab in self.getFitTabs():
+            symbol_dict.update(tab.getSymbolDict())
+        return symbol_dict
+
+    def getConstraintTab(self):
+        """
+        Returns the constraint tab, or None if no constraint tab is active
+        """
+        if any(isinstance(tab, ConstraintWidget) for tab in self.tabs):
+            constraint_tab = next(tab
+                                  for tab in self.tabs
+                                  if isinstance(tab, ConstraintWidget))
+        else:
+            constraint_tab = None
+        return constraint_tab
+
+    def getTabByName(self, name):
+        """
+        Returns the tab with with attribute name *name*
+        """
+        assert(name, str)
+        for tab in self.tabs:
+            if tab.modelName() == name:
+                return tab
+        return None
