@@ -164,8 +164,9 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
         if self._allowClose:
             # reset the closability flag
             self.setClosable(value=False)
-            # Tell the MdiArea to close the container
-            self.parentWidget().close()
+            # Tell the MdiArea to close the container if it is visible
+            if self.parentWidget():
+                self.parentWidget().close()
             event.accept()
         else:
             event.ignore()
@@ -199,14 +200,12 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
 
         self.backgroundInput.textChanged.connect(
             lambda: self.set_background(self.backgroundInput.text()))
-        self.minQInput.textChanged.connect(
-            lambda: self._calculator.set_qmin(is_float(self.minQInput.text())))
         self.regularizationConstantInput.textChanged.connect(
             lambda: self._calculator.set_alpha(is_float(self.regularizationConstantInput.text())))
         self.maxDistanceInput.textChanged.connect(
             lambda: self._calculator.set_dmax(is_float(self.maxDistanceInput.text())))
-        self.maxQInput.textChanged.connect(
-            lambda: self._calculator.set_qmax(is_float(self.maxQInput.text())))
+        self.maxQInput.editingFinished.connect(self.check_q_high)
+        self.minQInput.editingFinished.connect(self.check_q_low)
         self.slitHeightInput.textChanged.connect(
             lambda: self._calculator.set_slit_height(is_float(self.slitHeightInput.text())))
         self.slitWidthInput.textChanged.connect(
@@ -342,13 +341,13 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
             self.logic.data_is_loaded and
             self._calculator.nfunc != self.nTermsSuggested)
 
-    def populateDataComboBox(self, filename, data_ref):
+    def populateDataComboBox(self, name, data_ref):
         """
-        Append a new file name to the data combobox
-        :param filename: data filename
+        Append a new name to the data combobox
+        :param name: data name
         :param data_ref: QStandardItem reference for data set to be added
         """
-        self.dataList.addItem(filename, data_ref)
+        self.dataList.addItem(name, data_ref)
 
     def acceptNoTerms(self):
         """Send estimated no of terms to input"""
@@ -434,7 +433,7 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
     def showBatchOutput(self):
         """
         Display the batch output in tabular form
-        :param output_data: Dictionary mapping filename -> P(r) instance
+        :param output_data: Dictionary mapping name -> P(r) instance
         """
         if self.batchResultsWindow is None:
             self.batchResultsWindow = BatchInversionOutputPanel(
@@ -455,6 +454,46 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
         self.isCalculating = False
         self.updateGuiValues()
 
+    def check_q_low(self, q_value=None):
+        """ Validate the low q value """
+        if not q_value:
+            q_value = float(self.minQInput.text()) if self.minQInput.text() else ''
+        if q_value == '':
+            self.model.setItem(WIDGETS.W_QMIN, QtGui.QStandardItem(q_value))
+            return
+        q_min = min(self._calculator.x) if any(self._calculator.x) else -1 * np.inf
+        q_max = self._calculator.get_qmax() if self._calculator.get_qmax() is not None else np.inf
+        if q_value > q_max:
+            # Value too high - coerce to max q
+            self.model.setItem(WIDGETS.W_QMIN, QtGui.QStandardItem("{:.4g}".format(q_max)))
+        elif q_value < q_min:
+            # Value too low - coerce to min q
+            self.model.setItem(WIDGETS.W_QMIN, QtGui.QStandardItem("{:.4g}".format(q_min)))
+        else:
+            # Valid Q - set model item
+            self.model.setItem(WIDGETS.W_QMIN, QtGui.QStandardItem("{:.4g}".format(q_value)))
+            self._calculator.set_qmin(q_value)
+
+    def check_q_high(self, q_value=None):
+        """ Validate the value of high q sent by the slider """
+        if not q_value:
+            q_value = float(self.maxQInput.text()) if self.maxQInput.text() else ''
+        if q_value == '':
+            self.model.setItem(WIDGETS.W_QMAX, QtGui.QStandardItem(q_value))
+            return
+        q_max = max(self._calculator.x) if any(self._calculator.x) else np.inf
+        q_min = self._calculator.get_qmin() if self._calculator.get_qmin() is not None else -1 * np.inf
+        if q_value > q_max:
+            # Value too high - coerce to max q
+            self.model.setItem(WIDGETS.W_QMAX, QtGui.QStandardItem("{:.4g}".format(q_max)))
+        elif q_value < q_min:
+            # Value too low - coerce to min q
+            self.model.setItem(WIDGETS.W_QMAX, QtGui.QStandardItem("{:.4g}".format(q_min)))
+        else:
+            # Valid Q - set model item
+            self.model.setItem(WIDGETS.W_QMAX, QtGui.QStandardItem("{:.4g}".format(q_value)))
+            self._calculator.set_qmax(q_value)
+
     ######################################################################
     # Response Actions
 
@@ -487,7 +526,7 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
             if np.size(self.logic.data.dy) == 0 or np.all(self.logic.data.dy) == 0:
                 self.logic.add_errors()
             self.updateDataList(data)
-            self.populateDataComboBox(self.logic.data.filename, data)
+            self.populateDataComboBox(self.logic.data.name, data)
         self.dataList.setCurrentIndex(len(self.dataList) - 1)
         #Checking for 1D again to mitigate the case when 2D data is last on the data list
         if isinstance(self.logic.data, Data1D):
@@ -503,7 +542,7 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
             DICT_KEYS[2]: self.dataPlot
         }
         # Update batch results window when finished
-        self.batchResults[self.logic.data.filename] = self._calculator
+        self.batchResults[self.logic.data.name] = self._calculator
         if self.batchResultsWindow is not None:
             self.showBatchOutput()
 
@@ -689,7 +728,7 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
         """
         # Get all parameters from page
         param_dict = self.getState()
-        param_dict['data_name'] = str(self.logic.data.filename)
+        param_dict['data_name'] = str(self.logic.data.name)
         param_dict['data_id'] = str(self.logic.data.id)
         return param_dict
 
@@ -1004,10 +1043,17 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
 
         # Update P(r) and fit plots
         self.prPlot = self.logic.newPRPlot(out, self._calculator, cov)
+        self.prPlot.show_yzero = True
         self.prPlot.filename = self.logic.data.filename
         self.dataPlot = self.logic.new1DPlot(out, self._calculator)
         self.dataPlot.filename = self.logic.data.filename
 
+        self.dataPlot.show_q_range_sliders = True
+        self.dataPlot.slider_low_q_input = self.minQInput
+        self.dataPlot.slider_low_q_setter = self.check_q_low
+        self.dataPlot.slider_high_q_input = self.maxQInput
+        self.dataPlot.slider_high_q_setter = self.check_q_high
+
         # Udpate internals and GUI
         self.updateDataList(self._data)
         if self.isBatch:
