@@ -8,15 +8,15 @@
     http://www.smallangles.net/wgwiki/index.php/cansas1d_documentation
 """
 #####################################################################
-#This software was developed by the University of Tennessee as part of the
-#Distributed Data Analysis of Neutron Scattering Experiments (DANSE)
-#project funded by the US National Science Foundation.
-#See the license text in license.txt
-#copyright 2008, University of Tennessee
+# This software was developed by the University of Tennessee as part of the
+# Distributed Data Analysis of Neutron Scattering Experiments (DANSE)
+# project funded by the US National Science Foundation.
+# See the license text in license.txt
+# copyright 2008, University of Tennessee
 ######################################################################
 
-#TODO: Keep track of data manipulation in the 'process' data structure.
-#TODO: This module should be independent of plottables. We should write
+# TODO: Keep track of data manipulation in the 'process' data structure.
+# TODO: This module should be independent of plottables. We should write
 #        an adapter class for plottables when needed.
 
 from __future__ import print_function
@@ -27,9 +27,9 @@ import copy
 
 import numpy as np
 
-#from sas.guitools.plottables import Data1D as plottable_1D
 from sas.sascalc.data_util.uncertainty import Uncertainty
 
+
 class plottable_1D(object):
     """
     Data1D is a place holder for 1D plottables.
@@ -40,11 +40,11 @@ class plottable_1D(object):
     y = None
     dx = None
     dy = None
-    ## Slit smearing length
+    # Slit smearing length
     dxl = None
-    ## Slit smearing width
+    # Slit smearing width
     dxw = None
-    ## SESANS specific params (wavelengths for spin echo length calculation)
+    # SESANS specific params (wavelengths for spin echo length calculation)
     lam = None
     dlam = None
 
@@ -54,7 +54,8 @@ class plottable_1D(object):
     _yaxis = ''
     _yunit = ''
 
-    def __init__(self, x, y, dx=None, dy=None, dxl=None, dxw=None, lam=None, dlam=None):
+    def __init__(self, x, y, dx=None, dy=None, dxl=None, dxw=None,
+                 lam=None, dlam=None):
         self.x = np.asarray(x)
         self.y = np.asarray(y)
         if dx is not None:
@@ -101,6 +102,8 @@ class plottable_2D(object):
     dqx_data = None
     dqy_data = None
     mask = None
+    x_bins = None
+    y_bins = None
 
     # Units
     _xaxis = ''
@@ -113,7 +116,8 @@ class plottable_2D(object):
     def __init__(self, data=None, err_data=None, qx_data=None,
                  qy_data=None, q_data=None, mask=None,
                  dqx_data=None, dqy_data=None, xmin=None, xmax=None,
-                 ymin=None, ymax=None, zmin=None, zmax=None):
+                 ymin=None, ymax=None, zmin=None, zmax=None,
+                 x_bins=None, y_bins=None):
         self.data = np.asarray(data)
         self.qx_data = np.asarray(qx_data)
         self.qy_data = np.asarray(qy_data)
@@ -137,6 +141,9 @@ class plottable_2D(object):
         self.zmin = zmin
         self.zmax = zmax
 
+        self.y_bins = x_bins if x_bins else []
+        self.x_bins = y_bins if y_bins else []
+
     def xaxis(self, label, unit):
         """
         set the x axis label and unit
@@ -163,11 +170,11 @@ class Vector(object):
     """
     Vector class to hold multi-dimensional objects
     """
-    ## x component
+    # x component
     x = None
-    ## y component
+    # y component
     y = None
-    ## z component
+    # z component
     z = None
 
     def __init__(self, x=None, y=None, z=None):
@@ -192,27 +199,27 @@ class Detector(object):
     """
     Class to hold detector information
     """
-    ## Name of the instrument [string]
+    # Name of the instrument [string]
     name = None
-    ## Sample to detector distance [float] [mm]
+    # Sample to detector distance [float] [mm]
     distance = None
     distance_unit = 'mm'
-    ## Offset of this detector position in X, Y,
-    #(and Z if necessary) [Vector] [mm]
+    # Offset of this detector position in X, Y,
+    # (and Z if necessary) [Vector] [mm]
     offset = None
     offset_unit = 'm'
-    ## Orientation (rotation) of this detector in roll,
+    # Orientation (rotation) of this detector in roll,
     # pitch, and yaw [Vector] [degrees]
     orientation = None
     orientation_unit = 'degree'
-    ## Center of the beam on the detector in X and Y
-    #(and Z if necessary) [Vector] [mm]
+    # Center of the beam on the detector in X and Y
+    # (and Z if necessary) [Vector] [mm]
     beam_center = None
     beam_center_unit = 'mm'
-    ## Pixel size in X, Y, (and Z if necessary) [Vector] [mm]
+    # Pixel size in X, Y, (and Z if necessary) [Vector] [mm]
     pixel_size = None
     pixel_size_unit = 'mm'
-    ## Slit length of the instrument for this detector.[float] [mm]
+    # Slit length of the instrument for this detector.[float] [mm]
     slit_length = None
     slit_length_unit = 'mm'
 
@@ -244,16 +251,16 @@ class Detector(object):
 
 
 class Aperture(object):
-    ## Name
+    # Name
     name = None
-    ## Type
+    # Type
     type = None
-    ## Size name
+    # Size name
     size_name = None
-    ## Aperture size [Vector]
+    # Aperture size [Vector]
     size = None
     size_unit = 'mm'
-    ## Aperture distance [float]
+    # Aperture distance [float]
     distance = None
     distance_unit = 'mm'
 
@@ -265,12 +272,12 @@ class Collimation(object):
     """
     Class to hold collimation information
     """
-    ## Name
+    # Name
     name = None
-    ## Length [float] [mm]
+    # Length [float] [mm]
     length = None
     length_unit = 'mm'
-    ## Aperture
+    # Aperture
     aperture = None
 
     def __init__(self):
@@ -292,7 +299,7 @@ class Source(object):
     """
     Class to hold source information
     """
-    ## Name
+    # Name
     name = None
     # Generic radiation type (Type and probe give more specific info) [string]
     radiation = None
@@ -301,23 +308,23 @@ class Source(object):
     type = None
     # Radiation probe (generic probe such as neutron, x-ray, muon, etc) [string]
     probe = None
-    ## Beam size name
+    # Beam size name
     beam_size_name = None
-    ## Beam size [Vector] [mm]
+    # Beam size [Vector] [mm]
     beam_size = None
     beam_size_unit = 'mm'
-    ## Beam shape [string]
+    # Beam shape [string]
     beam_shape = None
-    ## Wavelength [float] [Angstrom]
+    # Wavelength [float] [Angstrom]
     wavelength = None
     wavelength_unit = 'A'
-    ## Minimum wavelength [float] [Angstrom]
+    # Minimum wavelength [float] [Angstrom]
     wavelength_min = None
     wavelength_min_unit = 'nm'
-    ## Maximum wavelength [float] [Angstrom]
+    # Maximum wavelength [float] [Angstrom]
     wavelength_max = None
     wavelength_max_unit = 'nm'
-    ## Wavelength spread [float] [Angstrom]
+    # Wavelength spread [float] [Angstrom]
     wavelength_spread = None
     wavelength_spread_unit = 'percent'
 
@@ -357,27 +364,27 @@ class Sample(object):
     """
     Class to hold the sample description
     """
-    ## Short name for sample
+    # Short name for sample
     name = ''
-    ## ID
+    # ID
     ID = ''
-    ## Thickness [float] [mm]
+    # Thickness [float] [mm]
     thickness = None
     thickness_unit = 'mm'
-    ## Transmission [float] [fraction]
+    # Transmission [float] [fraction]
     transmission = None
-    ## Temperature [float] [No Default]
+    # Temperature [float] [No Default]
     temperature = None
     temperature_unit = None
-    ## Position [Vector] [mm]
+    # Position [Vector] [mm]
     position = None
     position_unit = 'mm'
-    ## Orientation [Vector] [degrees]
+    # Orientation [Vector] [degrees]
     orientation = None
     orientation_unit = 'degree'
-    ## Details
+    # Details
     details = None
-    ## SESANS zacceptance
+    # SESANS zacceptance
     zacceptance = (0,"")
     yacceptance = (0,"")
 
@@ -425,8 +432,9 @@ class Process(object):
         """
             Return True if the object is empty
         """
-        return len(self.name) == 0 and len(self.date) == 0 and len(self.description) == 0 \
-            and len(self.term) == 0 and len(self.notes) == 0
+        return (len(self.name) == 0 and len(self.date) == 0
+                and len(self.description) == 0 and len(self.term) == 0
+                and len(self.notes) == 0)
 
     def single_line_desc(self):
         """
@@ -453,13 +461,13 @@ class TransmissionSpectrum(object):
     """
     name = ''
     timestamp = ''
-    ## Wavelength (float) [A]
+    # Wavelength (float) [A]
     wavelength = None
     wavelength_unit = 'A'
-    ## Transmission (float) [unit less]
+    # Transmission (float) [unit less]
     transmission = None
     transmission_unit = ''
-    ## Transmission Deviation (float) [unit less]
+    # Transmission Deviation (float) [unit less]
     transmission_deviation = None
     transmission_deviation_unit = ''
 
@@ -474,10 +482,10 @@ class TransmissionSpectrum(object):
         _str += "   Timestamp:        \t{0}\n".format(self.timestamp)
         _str += "   Wavelength unit:  \t{0}\n".format(self.wavelength_unit)
         _str += "   Transmission unit:\t{0}\n".format(self.transmission_unit)
-        _str += "   Trans. Dev. unit:  \t{0}\n".format(\
+        _str += "   Trans. Dev. unit:  \t{0}\n".format(
                                             self.transmission_deviation_unit)
-        length_list = [len(self.wavelength), len(self.transmission), \
-                len(self.transmission_deviation)]
+        length_list = [len(self.wavelength), len(self.transmission),
+                       len(self.transmission_deviation)]
         _str += "   Number of Pts:    \t{0}\n".format(max(length_list))
         return _str
 
@@ -489,70 +497,69 @@ class DataInfo(object):
     instrument description, the sample description,
     the data itself and any other meta data.
     """
-    ## Title
+    # Title
     title = ''
-    ## Run number
+    # Run number
     run = None
-    ## Run name
+    # Run name
     run_name = None
-    ## File name
+    # File name
     filename = ''
-    ## Notes
+    # Notes
     notes = None
-    ## Processes (Action on the data)
+    # Processes (Action on the data)
     process = None
-    ## Instrument name
+    # Instrument name
     instrument = ''
-    ## Detector information
+    # Detector information
     detector = None
-    ## Sample information
+    # Sample information
     sample = None
-    ## Source information
+    # Source information
     source = None
-    ## Collimation information
+    # Collimation information
     collimation = None
-    ## Transmission Spectrum INfo
+    # Transmission Spectrum INfo
     trans_spectrum = None
-    ## Additional meta-data
+    # Additional meta-data
     meta_data = None
-    ## Loading errors
+    # Loading errors
     errors = None
-    ## SESANS data check
+    # SESANS data check
     isSesans = None
 
-
     def __init__(self):
         """
         Initialization
         """
-        ## Title
+        # Title
         self.title = ''
-        ## Run number
+        # Run number
         self.run = []
         self.run_name = {}
-        ## File name
+        # File name
         self.filename = ''
-        ## Notes
+        # Notes
         self.notes = []
-        ## Processes (Action on the data)
+        # Processes (Action on the data)
         self.process = []
-        ## Instrument name
+        # Instrument name
         self.instrument = ''
-        ## Detector information
+        # Detector information
         self.detector = []
-        ## Sample information
+        # Sample information
         self.sample = Sample()
-        ## Source information
+        # Source information
         self.source = Source()
-        ## Collimation information
+        # Collimation information
         self.collimation = []
-        ## Transmission Spectrum
+        # Transmission Spectrum
         self.trans_spectrum = []
-        ## Additional meta-data
+        # Additional meta-data
         self.meta_data = {}
-        ## Loading errors
+        # Loading errors
         self.errors = []
-        ## SESANS data check
+        # SESANS data check
         self.isSesans = False
 
     def append_empty_process(self):
@@ -570,23 +577,23 @@ class DataInfo(object):
         """
         Nice printout
         """
-        _str = "File:            %s\n" % self.filename
-        _str += "Title:           %s\n" % self.title
-        _str += "Run:             %s\n" % str(self.run)
-        _str += "SESANS:          %s\n" % str(self.isSesans)
-        _str += "Instrument:      %s\n" % str(self.instrument)
-        _str += "%s\n" % str(self.sample)
-        _str += "%s\n" % str(self.source)
+        _str = f"File:            {self.filename}\n"
+        _str += f"Title:           {self.title}\n"
+        _str += f"Run:             {self.run}\n"
+        _str += f"SESANS:          {self.isSesans}\n"
+        _str += f"Instrument:      {self.instrument}\n"
+        _str += f"{str(self.sample)}\n"
+        _str += f"{str(self.source)}\n"
         for item in self.detector:
-            _str += "%s\n" % str(item)
+            _str += f"{str(item)}\n"
         for item in self.collimation:
-            _str += "%s\n" % str(item)
+            _str += f"{str(item)}\n"
         for item in self.process:
-            _str += "%s\n" % str(item)
+            _str += f"{str(item)}\n"
         for item in self.notes:
-            _str += "%s\n" % str(item)
+            _str += f"{str(item)}\n"
         for item in self.trans_spectrum:
-            _str += "%s\n" % str(item)
+            _str += f"{str(item)}\n"
         return _str
 
     # Private method to perform operation. Not implemented for DataInfo,
@@ -726,23 +733,25 @@ class DataInfo(object):
         """
         return self._perform_union(other)
 
+
 class Data1D(plottable_1D, DataInfo):
     """
     1D data class
     """
-    def __init__(self, x=None, y=None, dx=None, dy=None, lam=None, dlam=None, isSesans=False):
+    def __init__(self, x=None, y=None, dx=None, dy=None,
+                 lam=None, dlam=None, isSesans=False):
         DataInfo.__init__(self)
         plottable_1D.__init__(self, x, y, dx, dy, None, None, lam, dlam)
         self.isSesans = isSesans
         try:
-            if self.isSesans: # the data is SESANS
+            if self.isSesans:  # the data is SESANS
                 self.x_unit = 'A'
                 self.y_unit = 'pol'
-            elif not self.isSesans: # the data is SANS
+            elif not self.isSesans:  # the data is SANS
                 self.x_unit = '1/A'
                 self.y_unit = '1/cm'
-        except: # the data is not recognized/supported, and the user is notified
-            raise TypeError('data not recognized, check documentation for supported 1D data formats')
+        except Exception:  # the data is not recognized, notifying user
+            raise TypeError('Check documentation for supported 1D data formats')
 
     def __str__(self):
         """
@@ -762,10 +771,8 @@ class Data1D(plottable_1D, DataInfo):
         :return: True is slit smearing info is present, False otherwise
         """
         def _check(v):
-            if (v.__class__ == list or v.__class__ == np.ndarray) \
-                and len(v) > 0 and min(v) > 0:
-                return True
-            return False
+            return ((v.__class__ == list or v.__class__ == np.ndarray)
+                    and len(v) > 0 and min(v) > 0)
         return _check(self.dxl) or _check(self.dxw)
 
     def clone_without_data(self, length=0, clone=None):
@@ -838,8 +845,7 @@ class Data1D(plottable_1D, DataInfo):
         dy_other = None
         if isinstance(other, Data1D):
             # Check that data lengths are the same
-            if len(self.x) != len(other.x) or \
-                len(self.y) != len(other.y):
+            if len(self.x) != len(other.x) or len(self.y) != len(other.y):
                 msg = "Unable to perform operation: data length are not equal"
                 raise ValueError(msg)
             # Here we could also extrapolate between data points
@@ -948,7 +954,7 @@ class Data1D(plottable_1D, DataInfo):
             result.dxl = np.zeros(len(self.x) + len(other.x))
 
         result.x = np.append(self.x, other.x)
-        #argsorting
+        # argsorting
         ind = np.argsort(result.x)
         result.x = result.x[ind]
         result.y = np.append(self.y, other.y)
@@ -972,15 +978,11 @@ class Data2D(plottable_2D, DataInfo):
     """
     2D data class
     """
-    ## Units for Q-values
+    # Units for Q-values
     Q_unit = '1/A'
-    ## Units for I(Q) values
+    # Units for I(Q) values
     I_unit = '1/cm'
-    ## Vector of Q-values at the center of each bin in x
-    x_bins = None
-    ## Vector of Q-values at the center of each bin in y
-    y_bins = None
-    ## No 2D SESANS data as of yet. Always set it to False
+    # No 2D SESANS data as of yet. Always set it to False
     isSesans = False
 
     def __init__(self, data=None, err_data=None, qx_data=None,
@@ -994,8 +996,6 @@ class Data2D(plottable_2D, DataInfo):
                               dqx_data=dqx_data, dqy_data=dqy_data,
                               q_data=q_data, mask=mask, xmin=xmin, xmax=xmax,
                               ymin=ymin, ymax=ymax, zmin=zmin, zmax=zmax)
-        self.y_bins = []
-        self.x_bins = []
 
         if len(self.detector) > 0:
             raise RuntimeError("Data2D: Detector bank already filled at init")
@@ -1008,7 +1008,8 @@ class Data2D(plottable_2D, DataInfo):
         _str += "   Y-axis:       %s\t[%s]\n" % (self._yaxis, self._yunit)
         _str += "   Z-axis:       %s\t[%s]\n" % (self._zaxis, self._zunit)
         _str += "   Length:       %g \n" % (len(self.data))
-        _str += "   Shape:        (%d, %d)\n" % (len(self.y_bins), len(self.x_bins))
+        _str += "   Shape:        (%d, %d)\n" % (len(self.y_bins),
+                                                 len(self.x_bins))
         return _str
 
     def clone_without_data(self, length=0, clone=None):
@@ -1029,8 +1030,6 @@ class Data2D(plottable_2D, DataInfo):
             qy_data = np.zeros(length)
             q_data = np.zeros(length)
             mask = np.zeros(length)
-            dqx_data = None
-            dqy_data = None
             clone = Data2D(data=data, err_data=err_data,
                            qx_data=qx_data, qy_data=qy_data,
                            q_data=q_data, mask=mask)
@@ -1102,31 +1101,33 @@ class Data2D(plottable_2D, DataInfo):
         """
         err_other = None
         TOLERANCE = 0.01
+        msg_base = "Incompatible data sets: q-values do not match: "
         if isinstance(other, Data2D):
             # Check that data lengths are the same
-            if len(self.data) != len(other.data) or \
-                len(self.qx_data) != len(other.qx_data) or \
-                len(self.qy_data) != len(other.qy_data):
+            if (len(self.data) != len(other.data)
+                    or len(self.qx_data) != len(other.qx_data)
+                    or len(self.qy_data) != len(other.qy_data)):
                 msg = "Unable to perform operation: data length are not equal"
                 raise ValueError(msg)
             for ind in range(len(self.data)):
-                if fabs(self.qx_data[ind] - other.qx_data[ind]) > fabs(self.qx_data[ind])*TOLERANCE:
-                    msg = "Incompatible data sets: qx-values do not match: %s %s" % (self.qx_data[ind], other.qx_data[ind])
+                if (fabs(self.qx_data[ind] - other.qx_data[ind])
+                        > fabs(self.qx_data[ind])*TOLERANCE):
+                    msg = f"{msg_base}{self.qx_data[ind]} {other.qx_data[ind]}"
                     raise ValueError(msg)
-                if fabs(self.qy_data[ind] - other.qy_data[ind]) > fabs(self.qy_data[ind])*TOLERANCE:
-                    msg = "Incompatible data sets: qy-values do not match: %s %s" % (self.qy_data[ind], other.qy_data[ind])
+                if (fabs(self.qy_data[ind] - other.qy_data[ind])
+                        > fabs(self.qy_data[ind])*TOLERANCE):
+                    msg = f"{msg_base}{self.qy_data[ind]} {other.qy_data[ind]}"
                     raise ValueError(msg)
 
             # Check that the scales match
             err_other = other.err_data
-            if other.err_data is None or \
-                (len(other.err_data) != len(other.data)):
+            if (other.err_data is None
+                    or (len(other.err_data) != len(other.data))):
                 err_other = np.zeros(len(other.data))
 
         # Check that we have errors, otherwise create zero vector
         err = self.err_data
-        if self.err_data is None or \
-            (len(self.err_data) != len(self.data)):
+        if self.err_data is None or (len(self.err_data) != len(self.data)):
             err = np.zeros(len(other.data))
         return err, err_other
 
@@ -1148,8 +1149,8 @@ class Data2D(plottable_2D, DataInfo):
             result.dqy_data = np.zeros(len(self.data))
         for i in range(np.size(self.data)):
             result.data[i] = self.data[i]
-            if self.err_data is not None and \
-                            np.size(self.data) == np.size(self.err_data):
+            if (self.err_data is not None
+                    and np.size(self.data) == np.size(self.err_data)):
                 result.err_data[i] = self.err_data[i]
             if self.dqx_data is not None:
                 result.dqx_data[i] = self.dqx_data[i]
@@ -1163,14 +1164,12 @@ class Data2D(plottable_2D, DataInfo):
             a = Uncertainty(self.data[i], dy[i]**2)
             if isinstance(other, Data2D):
                 b = Uncertainty(other.data[i], dy_other[i]**2)
-                if other.dqx_data is not None and \
-                        result.dqx_data is not None:
+                if other.dqx_data is not None and result.dqx_data is not None:
                     result.dqx_data[i] *= self.dqx_data[i]
                     result.dqx_data[i] += (other.dqx_data[i]**2)
                     result.dqx_data[i] /= 2
                     result.dqx_data[i] = math.sqrt(result.dqx_data[i])
-                if other.dqy_data is not None and \
-                        result.dqy_data is not None:
+                if other.dqy_data is not None and result.dqy_data is not None:
                     result.dqy_data[i] *= self.dqy_data[i]
                     result.dqy_data[i] += (other.dqy_data[i]**2)
                     result.dqy_data[i] /= 2
@@ -1182,6 +1181,7 @@ class Data2D(plottable_2D, DataInfo):
             result.err_data[i] = math.sqrt(math.fabs(output.variance))
         return result
 
+    @staticmethod
     def _validity_check_union(self, other):
         """
         Checks that the data lengths are compatible.
@@ -1208,21 +1208,19 @@ class Data2D(plottable_2D, DataInfo):
         """
         # First, check the data compatibility
         self._validity_check_union(other)
-        result = self.clone_without_data(np.size(self.data) + \
-                                         np.size(other.data))
+        result = self.clone_without_data(np.size(self.data)
+                                         + np.size(other.data))
         result.xmin = self.xmin
         result.xmax = self.xmax
         result.ymin = self.ymin
         result.ymax = self.ymax
-        if self.dqx_data is None or self.dqy_data is None or \
-                other.dqx_data is None or other.dqy_data is None:
+        if (self.dqx_data is None or self.dqy_data is None
+                or other.dqx_data is None or other.dqy_data is None):
             result.dqx_data = None
             result.dqy_data = None
         else:
-            result.dqx_data = np.zeros(len(self.data) + \
-                                       np.size(other.data))
-            result.dqy_data = np.zeros(len(self.data) + \
-                                       np.size(other.data))
+            result.dqx_data = np.zeros(len(self.data) + np.size(other.data))
+            result.dqy_data = np.zeros(len(self.data) + np.size(other.data))
 
         result.data = np.append(self.data, other.data)
         result.qx_data = np.append(self.qx_data, other.qx_data)
@@ -1245,10 +1243,10 @@ def combine_data_info_with_plottable(data, datainfo):
     plottable_1D or 2D data object.
 
     :param data: A plottable_1D or plottable_2D data object
+    :param datainfo: A DataInfo object to be combined with the plottable
     :return: A fully specified Data1D or Data2D object
     """
 
-    final_dataset = None
     if isinstance(data, plottable_1D):
         final_dataset = Data1D(data.x, data.y, isSesans=datainfo.isSesans)
         final_dataset.dx = data.dx
@@ -1266,6 +1264,8 @@ def combine_data_info_with_plottable(data, datainfo):
         final_dataset.xaxis(data._xaxis, data._xunit)
         final_dataset.yaxis(data._yaxis, data._yunit)
         final_dataset.zaxis(data._zaxis, data._zunit)
+        final_dataset.x_bins = data.x_bins
+        final_dataset.y_bins = data.y_bins
     else:
         return_string = ("Should Never Happen: _combine_data_info_with_plottabl"
                          "e input is not a plottable1d or plottable2d data "
